screenSize=(1024,768)

from math import radians

from OpenGL.GL import *
from OpenGL.GLU import *

import pygame
from pygame.locals import *

def resize(width, height):
    glViewport(0,0, width, height)
    glMatrixMode(GL_PROJECTION)
    glLoadIdentity()
    gluPerspective(60.0,float(width)/height,.1,1000.)
    glMatrixMode(GL_MODELVIEW)
    glLoadIdentity()

def init():
    glEnable(GL_DEPTH_TEST)
    glEnable(GL_TEXTURE_2D)
    glClearColor(1,1,1,1)

class cube(object):
    def __init__(self):
        pass

    numFaces=6

    vertices= [(0.0,0.0,150.0),
               (150.0,0.0,150.0),
               (150.0,150.0,150.0),
               (0.0,150.0,150.0),
               (0.0,0.0,0.0),
               (150.0,0.0,0.0),
               (150.0,150.0,0.0),
               (0.0,150.0,0.0)]

    normals= [(0.0,0.0,+1.0), #front
              (0.0,0.0,-1.0), #back
              (+1.0,0.0,0.0), #right
              (-1.0,0.0,0.0), #left
              (0.0,+1.0,0.0), #top
              (0.0,-1.0,0.0)] #bottom

    vertexIndices = [(0,1,2,3), #front
                     (4,5,6,7), #back
                     (1,5,6,2), #right
                     (0,4,7,3), #left
                     (3,2,6,7), #top
                     (0,1,5,4)] #bottom

   

    def render(self):

           
        glBegin(GL_QUADS)

        for faceNo in xrange(self.numFaces):

            glNormal3dv(self.normals[faceNo])

            v1,v2,v3,v4=self.vertexIndices[faceNo]
            glTexCoord2f(0,1)
            glVertex( self.vertices[v1] )
            glTexCoord2f(1,1)
            glVertex( self.vertices[v2] )
            glTexCoord2f(1,0)
            glVertex( self.vertices[v3] )
            glTexCoord2f(0,0)
            glVertex( self.vertices[v4] )

        glEnd()


def run():
    pygame.init()
    screen=pygame.display.set_mode(screenSize, HWSURFACE|OPENGL|DOUBLEBUF)

    resize(*screenSize)
    init()

    textureSurface=pygame.image.load("testpic.png")
    textureData=pygame.image.tostring(textureSurface, 'RGB',True)

    textureId=glGenTextures(1)
    glBindTexture(GL_TEXTURE_2D,textureId)

    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER,GL_LINEAR)
    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER,GL_LINEAR)

    glPixelStorei(GL_UNPACK_ALIGNMENT,1)

    width, height= textureSurface.get_rect().size
    Cube=cube()

    glTexImage2D(GL_TEXTURE_2D,
                 0,
                 4,
                 width,
                 height,
                 0,
                 GL_RGB,
                 GL_UNSIGNED_BYTE,
                 textureData)

    clock = pygame.time.Clock()

    texRotation=0.0


    
    
    while True:
        for event in pygame.event.get():
            if event.type==QUIT:
                return
    
        timePassed=clock.tick()
        timePassedSeconds=timePassed/1000.
        texRotation+=timePassedSeconds*360.0/8.0

        glClear(GL_COLOR_BUFFER_BIT| GL_DEPTH_BUFFER_BIT);

        glLoadIdentity()

        glTranslate(0.0,0.0,-600.0)
        glRotate(texRotation,1,1,1)

        Cube.render()

        

        pygame.display.flip()

    glDeleteTextures(textureId)
    pygame.quit()

run()
